@@ -3,8 +3,9 @@ from __future__ import annotations
 import ckan.plugins as plugins
 import ckan.plugins.toolkit as toolkit
 
+from . import cli, views
 from .logic import action, auth
-from . import views, cli
+
 
 class CheckLinkPlugin(plugins.SingletonPlugin):
     plugins.implements(plugins.IConfigurer)
@@ -28,7 +29,6 @@ class CheckLinkPlugin(plugins.SingletonPlugin):
     def get_auth_functions(self):
         return auth.get_auth_functions()
 
-
     # IBlueprint
     def get_blueprint(self):
         return views.get_blueprints()
